package model;

/**
 * A component class for a CPU.
 * 
 * @author Kristian Torp, torp (at) cs (dot) aau (dot) dk.
 * @version 1.0
 */
public class CPU extends Component {
	/** Constant for frequency in mega hertz */
	public static final String MHZ = "MHz";

	/** Constant for frequency in giga hertz */
	public static final String GHZ = "GHz";

	/** The frequence of the cpu */
	private int frequence;

	/** The unit of the frequence */
	private String unit;

	/**
	 * Default constructor.
	 */
	public CPU() throws ModelException {
		this("", "", 0.0, 0, MHZ);
	}

	/**
	 * Constructor.
	 * 
	 * @param make
	 *            the make
	 * @param model
	 *            the model
	 * @param price
	 *            the price
	 * @param frequence
	 *            the frequency
	 */
	public CPU(String make, String model, double price, int frequence)
			throws ModelException {
		this(make, model, price, frequence, MHZ);
	}

	/**
	 * Constructor.
	 * 
	 * @param make
	 *            the make
	 * @param model
	 *            the model
	 * @param price
	 *            the price
	 * @param frequence
	 *            the frequency
	 * @param unit
	 *            the frequencey unit
	 */
	public CPU(String make, String model, double price, int frequence,
			String unit) throws ModelException {
		setMake(make);
		setModel(model);
		setPrice(price);
		setFrequence(frequence);
		setUnit(unit);
	}

	/**
	 * String representation of object.
	 * 
	 * @param o
	 *            the object to compare to
	 * @see java.lang.Object#toString(java.lang.Object)
	 */
	public String toString() {
		String res = "Make:      " + getMake() + "\n";
		res += "Model:     " + getModel() + "\n";
		res += "Price:     " + getPrice() + "\n";
		res += "Frequence: " + getFrequence() + getUnit();
		return res;
	}

	/**
	 * Checks for equality
	 * 
	 * @param o
	 *            the object to compare to
	 * @see java.lang.Object#equals(java.lang.Object)
	 */
	public boolean equals(Object o) {
		return o instanceof CPU && super.equals(o)
				&& this.getFrequence() == ((CPU) o).getFrequence()
				&& this.getUnit() == ((CPU) o).getUnit();
	}

	/**
	 * Creates a clone of the CPU
	 * 
	 * @see java.lang.Object#clone(java.lang.Object)
	 */
	public Object clone() {
		CPU copy;
		try {
			copy = new CPU(getMake(), getModel(), getPrice(), getFrequence(),
					getUnit());
		} catch (ModelException e) {
			throw new RuntimeException(e.getMessage());
		}
		return copy;
	}

	/**
	 * Sets the frequence of the cpu.
	 * 
	 * @param frequence
	 *            the frequence > 0
	 */
	public void setFrequence(int frequence) throws ModelException {
		// precondition
		if (frequence < 0) {
			throw new ModelException("Frequence must be larger than zero");
		}
		this.frequence = frequence;
	}

	/**
	 * Gets the frequence.
	 * 
	 * @return frequence
	 */
	public int getFrequence() {
		return frequence;
	}

	/**
	 * Sets the frequence unit.
	 * 
	 * @param unit
	 */
	public void setUnit(String unit) {
		this.unit = unit;
	}

	/**
	 * Gets the frequence unit.
	 * 
	 * @return frequence unit
	 */
	public String getUnit() {
		return unit;
	}
}