package model;

import java.io.*;

/**
 * The abstract component class. It is assumed that each a component can be
 * identified by its make and model.
 */
public abstract class Component implements Serializable {

	/** The make field */
	private String make;

	/** The model field */
	private String model;

	/** The price for the component */
	private double price;

	/**
	 * The default constructor.
	 * 
	 * @throws ModelException
	 */
	protected Component() throws ModelException {
		setMake("");
		setModel("");
		price = 0;
	}

	/**
	 * Creates a new component
	 * 
	 * @param make
	 *            the make
	 * @param model
	 *            the model
	 * @param price
	 *            the price
	 * @throws ModelException
	 */
	public Component(String make, String model, double price)
			throws ModelException {
		setMake(make);
		setModel(model);
		setPrice(price);
	}

	/**
	 * Checks that the entire object for equality.
	 * 
	 * @param o
	 *            the object to compare to
	 * @return true if the objects are equals; otherwise false
	 * @see java.lang.Object#equals(java.lang.Object)
	 */
	public boolean equals(Object o) {
		return o instanceof Component
				&& this.getMake().equals(((Component) o).getMake())
				&& this.getModel().equals(((Component) o).getModel())
				&& this.getPrice() == ((Component) o).getPrice();
	}

	/**
	 * Checks if the (make, model) is identical.
	 * 
	 * @return true if the (make, model) fields are equals; otherwise false
	 */
	public boolean idEquals(Component other) {
		if (other == null) {
			return false;
		}

		return this.getMake().equals(other.getMake())
				&& this.getModel().equals(other.getModel());
	}

	/**
	 * Sets the make of a component.
	 * 
	 * @make the new make
	 */
	public void setMake(String make) {
		this.make = make;
	}

	/**
	 * Gets the make of a component.
	 * 
	 * @return the make
	 */
	public String getMake() {
		return make;
	}

	/**
	 * Sets the model of a component.
	 * 
	 * @make the new make
	 */
	public void setModel(String model) {
		this.model = model;
	}

	/**
	 * Gets the model of a component.
	 * 
	 * @return the model
	 */
	public String getModel() {
		return model;
	}

	/**
	 * Sets the price of a component.
	 * 
	 * @make the new make
	 */
	public void setPrice(double price) throws ModelException {
		if (price < 0) {
			throw new ModelException("Price must be larger than zero");
		}

		this.price = price;
	}

	/**
	 * Gets the price of a component.
	 * 
	 * @return the price
	 */
	public double getPrice() {
		return price;
	}
}

