package model;

/**
 * A component class for a harddrive. It is assumed that the size of the hard
 * drive is always in giga bytes.
 * 
 * @author Kristian Torp, torp (at) cs (dot) aau (dot) dk.
 * @version 1.0
 */
public class HardDrive extends Storage {

	/**
	 * Default constructor.
	 * 
	 * @throws ModelException
	 */
	public HardDrive() throws ModelException {
		this("", "", 0.0, 0);
	}

	/**
	 * Constructor.
	 * 
	 * @param make
	 *            the make
	 * @param model
	 *            the model
	 * @param price
	 *            the price
	 * @param size
	 *            the size
	 * @throws ModelException
	 */
	public HardDrive(String make, String model, double price, int size)
			throws ModelException {
		super(make, model, price, size, Storage.GB);
	}

	/**
	 * Constructor.
	 * 
	 * @param make
	 *            the make
	 * @param model
	 *            the model
	 * @param price
	 *            the price
	 * @param size
	 *            the size
	 * @param unit
	 *            the unit
	 * @throws ModelException
	 */
	public HardDrive(String make, String model, double price, int size,
			String unit) throws ModelException {
		super(make, model, price, size, unit);
	}

	/**
	 * Creates a clone of the hard drive.
	 * 
	 * @see java.lang.Object#clone(java.lang.Object)
	 */
	public Object clone() {
		HardDrive copy;
		try {
			copy = new HardDrive(getMake(), getModel(), getPrice(), getSize(),
					getUnit());
		} catch (ModelException e) {
			throw new RuntimeException(e.getMessage());
		}
		return copy;
	}
}