package model;


/**
 * A component class for a main board.
 * 
 * @author Kristian Torp, torp (at) cs (dot) aau (dot) dk.
 * @version 1.0
 */
public class MainBoard extends Component{
    /** The textual information for a main board */
    private String information;
    
    /**
     * Default constructor.
     */
    public MainBoard() throws ModelException{
        this("", "", 0.0, "");
    }
    
    /**
     * Constructor.
     * @param make the make
     * @param model the model
     * @param price the price
     * @param information the information
     */
    public MainBoard(String make, String model, double price, String information) 
        throws ModelException{
        super();
        setMake(make);
        setModel(model);
        setPrice(price);
        setInformation(information);
    }
    
    /**
     * String representation of object.
     * @param o the object to compare to
     * @see java.lang.Object#toString(java.lang.Object)
     */
    public String toString(){
        String 
          res  = "Make:        " + getMake()  + "\n";
          res += "Model:       " + getModel() + "\n";
          res += "Price:       " + getPrice() + "\n";
          res += "Information: " + getInformation();
        return res;
    }
    
    /**
     * Checks for equality
     * @param o the object to compare to
     * @see java.lang.Object#equals(java.lang.Object)
     */
    public boolean equals(Object o){
        return o instanceof MainBoard && super.equals(o) &&
            this.getInformation() == ((MainBoard)o).getInformation();
    }
    
    /**
     * Creates a clone of the main board.
     * @see java.lang.Object#clone(java.lang.Object)
     */
    public Object clone(){
        MainBoard copy;
        try {
            copy = new MainBoard(getMake(), getModel(), getPrice(), getInformation());
        }
        catch (ModelException e){
            throw new RuntimeException(e.getMessage());
        }
        return copy;
    }

    /**
     * Sets the text information for a main board.
     * @param information the textual information
     */
    public void setInformation(String information){
        this.information = information;
    }
    
    /**
     * Gets the information.
     * @return the textual information
     */
    public String getInformation(){
        return information;
    }
}
