package model;


/**
 * A component class for a RAM module. It is assumed that the size of
 * the hard drive is always in mega bytes.
 * 
 * @author Kristian Torp, torp (at) cs (dot) aau (dot) dk.
 * @version 1.0
 */
public class RAM extends Storage{

    /**
     * Default constructor.
     */
    public RAM() throws ModelException{
        this("", "", 0.0, 0);
    }
    
    /**
     * Constructor.
     * @param make the make
     * @param model the model
     * @param price the price
     * @param size the size
     */
    public RAM(String make, String model, double price, int size) 
        throws ModelException{
        super(make, model, price, size, Storage.MB);
    }

    /**
     * Constructor.
     * @param make the make
     * @param model the model
     * @param price the price
     * @param size the size
     * @param unit the unit
     */
    public RAM(String make, String model, double price, int size, String unit) 
        throws ModelException{
        super(make, model, price, size, unit);
    }

    /**
     * Creates a clone of the RAM block.
     * @see java.lang.Object#clone(java.lang.Object)
     */
    public Object clone(){
        RAM copy;
        try {
            copy = new RAM(getMake(), getModel(), getPrice(), getSize(), getUnit());
        }
        catch (ModelException e){
            throw new RuntimeException(e.getMessage());
        }
        return copy;
    }
    
}
