package model;

/**
 * An abstract class for storage devices.
 * 
 * @author Kristian Torp, torp (at) cs (dot) aau (dot) dk.
 * @version 1.0
 */
public abstract class Storage extends Component{
    /** The constant for kilo bytes */
    public static final String KB = "KB";
    /** The constant for mega bytes */
    public static final String MB = "MB";
    /** The constant for giga bytes */
    public static final String GB = "GB";
        
    /** The size of the storage */
    private int size;
    /** The unit of the size, e.g., KB, MB, or GB */
    private String unit;

    /**
     * Default constructor.
     */
    public Storage() throws ModelException{
        this("", "", 0.0, 0, KB);
    }
    
    /**
     * Constructor.
     * @param make the make
     * @param model the model
     * @param price the price
     * @param size the size
     * @param unit the unit
     */
    public Storage(String make, String model, double price, int size, String unit) 
        throws ModelException{
        super();
        setMake(make);
        setModel(model);
        setPrice(price);
        setSize(size);
        setUnit(unit);
    }
    
   /**
     * String representation of object.
     * @param o the object to compare to
     * @see java.lang.Object#toString(java.lang.Object)
     */
    public String toString(){
        String 
          res  = "Make:  " + getMake()  + "\n";
          res += "Model: " + getModel() + "\n";
          res += "Price: " + getPrice() + "\n";
          res += "Size:  " + getSize()  + getUnit();
        return res;
    }
    
    /**
     * Checks for equality
     * @param o the object to compare to
     * @see java.lang.Object#equals(java.lang.Object)
     */
    public boolean equals(Object o){
        return o instanceof Storage &&
            super.equals(o) &&
            this.getSize()  == ((Storage)o).getSize()  &&
            this.getUnit()  == ((Storage)o).getUnit();
    }

    /**
     * Sets the size of the hard drive.
     * @param size the size in giga bytes
     */
    public void setSize(int size) throws ModelException{
        if (size < 0){
            throw new ModelException("Storage size must be larger than zero");
        }
        this.size = size;
    }

    /**
     * Gets the size.
     * @return hard drive size
     */
    public int getSize(){
        return size;
    }

    /**
     * Sets the unit of the size of the storage device.
     * @param unit the unit
     */
    public void setUnit(String unit){
        this.unit = unit;
    }

    /**
     * Gets the unit.
     * @return unit
     */
    public String getUnit(){
        return unit;
    }
}
